
import argparse 
  
def main(): 
  
    parser = argparse.ArgumentParser(prog ='gfg', 
                                     description ='GfG article demo package.') 
  
    parser.add_argument('integers', metavar ='N', type = int, nargs ='+', 
                        help ='an integer for the accumulator') 
    parser.add_argument('-greet', action ='store_const', const = True, 
                        default = False, dest ='greet', 
                        help ="Greet Message from Geeks For Geeks.") 
    parser.add_argument('--sum', dest ='accumulate', action ='store_const', 
                        const = sum, default = max, 
                        help ='sum the integers (default: find the max)') 
  
    args = parser.parse_args() 
  
    if args.greet: 
        print("Welcome to GeeksforGeeks !") 
        if args.accumulate == max: 
            print("The Computation Done is Maximum") 
        else: 
            print("The Computation Done is Summation") 
        print("And Here's your result:", end =" ")    
  
    print(args.accumulate(args.integers)) 




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

with open('requirements.txt') as f:
    requirements = f.readlines()

setuptools.setup(
    name="hitsquad",
    version="0.0.2",
    author="Shubham Arawkar",
    author_email="arawkar.shubham08@gmail.com",
    description="GGWP command broadcast over ssh",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    entry_points={
        "console_scripts": [
            "hitsquad = hitsquad.hitsquad:main"
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=requirements,
    python_requires='>=3.5',
)
